# Logo License

The DOLMa logo is a derivative of the following image:

- *origin*: U.S. Department of Agriculture (USDA) Pomological Watercolor Collection
- *source*: https://naldc.nal.usda.gov/catalog/POM00006082
- *license*: CC0
